summaryrefslogtreecommitdiffstats
path: root/src/systemtray.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/systemtray.cpp')
-rw-r--r--src/systemtray.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/systemtray.cpp b/src/systemtray.cpp
index 2b06ed0..bf6b91c 100644
--- a/src/systemtray.cpp
+++ b/src/systemtray.cpp
@@ -88,8 +88,8 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
// Some values we need:
TQPoint g = mapToGlobal(pos());
- int desktopWidth = kapp->desktop()->width();
- int desktopHeight = kapp->desktop()->height();
+ int desktopWidth = tdeApp->desktop()->width();
+ int desktopHeight = tdeApp->desktop()->height();
int tw = width();
int th = height();
@@ -121,24 +121,24 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
/* if (useSystray) {
// We are testing if one of the corners is hidden, and if yes, we would enter
// a time consuming process (raise kicker and wait some time):
-// if (kapp->widgetAt(g) != this ||
-// kapp->widgetAt(g + TQPoint(tw-1, 0)) != this ||
-// kapp->widgetAt(g + TQPoint(0, th-1)) != this ||
-// kapp->widgetAt(g + TQPoint(tw-1, th-1)) != this) {
+// if (tdeApp->widgetAt(g) != this ||
+// tdeApp->widgetAt(g + TQPoint(tw-1, 0)) != this ||
+// tdeApp->widgetAt(g + TQPoint(0, th-1)) != this ||
+// tdeApp->widgetAt(g + TQPoint(tw-1, th-1)) != this) {
int systrayManagerWinId = topLevelWidget()->winId();
KWin::forceActiveWindow(systrayManagerWinId);
- kapp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
+ tdeApp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
// KWin::activateWindow(systrayManagerWinId);
// kapp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
// KWin::raiseWindow(systrayManagerWinId);
// kapp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
sleep(1);
// TODO: Re-verify that at least one corner is now visible
// }
}*/
// KMessageBox::information(this, TQString::number(g.x()) + ":" + TQString::number(g.y()) + ":" +
-// TQString::number((int)(kapp->widgetAt(g+TQPoint(1,1)))));
+// TQString::number((int)(tdeApp->widgetAt(g+TQPoint(1,1)))));
TQString message = i18n(
"<p>Closing the main window will keep %1 running in the system tray. "
@@ -185,12 +185,12 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
// Associate source to image and show the dialog:
TQMimeSourceFactory::defaultFactory()->setPixmap("systray_shot", finalShot);
- KMessageBox::information(kapp->activeWindow(),
+ KMessageBox::information(tdeApp->activeWindow(),
message + "<p><center><img source=\"systray_shot\"></center></p>",
i18n("Docking in System Tray"), "hideOnCloseInfo");
TQMimeSourceFactory::defaultFactory()->setData("systray_shot", 0L);
} else {
- KMessageBox::information(kapp->activeWindow(),
+ KMessageBox::information(tdeApp->activeWindow(),
message,
i18n("Docking in System Tray"), "hideOnCloseInfo");
}
@@ -242,7 +242,7 @@ void SystemTray::mousePressEvent(TQMouseEvent *event)
event->accept();
} else if (event->button() & TQt::RightButton) { // Popup menu
TDEPopupMenu menu(this);
- menu.insertTitle( SmallIcon("basket"), kapp->aboutData()->programName() );
+ menu.insertTitle( SmallIcon("basket"), tdeApp->aboutData()->programName() );
Global::bnpView->actNewBasket->plug(&menu);
Global::bnpView->actNewSubBasket->plug(&menu);
@@ -435,8 +435,8 @@ void SystemTray::updateToolTipDelayed()
{
Basket *basket = Global::bnpView->currentBasket();
- TQString tip = "<p><nobr>" + ( basket->isLocked() ? kapp->makeStdCaption(i18n("%1 (Locked)"))
- : kapp->makeStdCaption( "%1") )
+ TQString tip = "<p><nobr>" + ( basket->isLocked() ? tdeApp->makeStdCaption(i18n("%1 (Locked)"))
+ : tdeApp->makeStdCaption( "%1") )
.arg(Tools::textToHTMLWithoutP(basket->basketName()));
TQToolTip::add(this, tip);
@@ -121,24 +121,24 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
// KWin::activateWindow(systrayManagerWinId);
-// kapp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
+// tdeApp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
// KWin::raiseWindow(systrayManagerWinId);
@@ -121,24 +121,24 @@ void KSystemTray2::displayCloseMessage(TQString fileMenu)
// KWin::raiseWindow(systrayManagerWinId);
-// kapp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
+// tdeApp->processEvents(); // Because without it the systrayManager is raised only after the messageBox is displayed
sleep(1);
// TODO: Re-verify that at least one corner is now visible